.. _ref-instruments:

===========
Instruments
===========

Gauges
======

.. automodule:: metrology.instruments.gauge
  :members:


Counters
========

.. automodule:: metrology.instruments.counter
    :members:

Derive
======

.. automodule:: metrology.instruments.derive
  :members:


Meters
======

.. automodule:: metrology.instruments.meter
  :members:

Histograms
==========

.. automodule:: metrology.instruments.histogram
  :members:


Timers and utilization timers
=============================

.. automodule:: metrology.instruments.timer
  :members:
  :inherited-members:


Health Checks
=============

.. automodule:: metrology.instruments.healthcheck
  :members:


Profilers
=========

.. automodule:: metrology.instruments.profiler
  :members:

